@@ -2,6 +2,7 @@ from collections import defaultdict
 from io import open
 import os
 import sys
+import shutil
 import traceback
 import logging
 import threading
@@ -137,6 +138,7 @@ class MyCli(object):
         self.multi_line = c['main'].as_bool('multi_line')
         self.key_bindings = c['main']['key_bindings']
         special.set_timing_enabled(c['main'].as_bool('timing'))
+        self.beep_after_seconds = float(c['main']['beep_after_seconds'] or 0)
 
         FavoriteQueries.instance = FavoriteQueries.from_config(self.config)
 
@@ -720,6 +722,8 @@ class MyCli(object):
                             self.output(formatted, status)
                         except KeyboardInterrupt:
                             pass
+                        if self.beep_after_seconds > 0 and t >= self.beep_after_seconds:
+                            self.echo('\a', err=True, nl=False)
                         if special.is_timing_enabled():
                             self.echo('Time: %0.03fs' % t)
                     except KeyboardInterrupt:
@@ -1054,7 +1058,7 @@ class MyCli(object):
         """Get the number of lines to reserve for the completion menu."""
         reserved_space_ratio = .45
         max_reserved_space = 8
-        _, height = click.get_terminal_size()
+        _, height = shutil.get_terminal_size()
         return min(int(round(height * reserved_space_ratio)), max_reserved_space)
 
     def get_last_query(self):
